@@ -8,15 +8,14 @@ This module contains various convenience utilities for working with and
 preparing input for nonrad.
 """
 
-from itertools import groupby
-from typing import List, Optional, Tuple
+from typing import List, Optional, Tuple, Union
 
 import numpy as np
+from pymatgen.core import Structure
+from pymatgen.io.vasp.outputs import Vasprun
 from scipy.optimize import curve_fit
 
 from nonrad.nonrad import AMU2KG, ANGS2M, EV2J, HBAR
-from pymatgen import Structure
-from pymatgen.io.vasp.outputs import Vasprun
 
 
 def get_cc_structures(
@@ -81,8 +80,9 @@ def get_dQ(ground: Structure, excited: Structure) -> float:
 def get_Q_from_struct(
         ground: Structure,
         excited: Structure,
-        struct: Structure,
-        tol: float = 1e-4
+        struct: Union[Structure, str],
+        tol: float = 1e-4,
+        nround: int = 5,
 ) -> float:
     """Calculate the Q value for a given structure.
 
@@ -101,6 +101,8 @@ def get_Q_from_struct(
     tol : float
         distance cutoff to throw away coordinates for determining Q (sites that
         don't move very far could introduce numerical noise)
+    nround : int
+        number of decimal places to round to in determining Q value
 
     Returns
     -------
@@ -108,18 +110,23 @@ def get_Q_from_struct(
         the Q value (amu^{1/2} Angstrom) of the structure
     """
     if isinstance(struct, str):
-        struct = Structure.from_file(struct)
+        tstruct = Structure.from_file(struct)
+    else:
+        tstruct = struct
 
     dQ = get_dQ(ground, excited)
-    possible_x = []
-    for i, site in enumerate(struct):
-        for j in range(3):
-            dx = excited[i].coords[j] - ground[i].coords[j]
-            if np.abs(dx) < tol:
-                continue
-            possible_x.append((site.coords[j] - ground[i].coords[j]) / dx)
-    spossible_x = np.sort(np.round(possible_x, 6))
-    return dQ * max(groupby(spossible_x), key=lambda x: len(list(x[1])))[0]
+
+    excited_coords = excited.cart_coords
+    ground_coords = ground.cart_coords
+    struct_coords = tstruct.cart_coords
+
+    dx = excited_coords - ground_coords
+    ind = np.abs(dx) > tol
+
+    poss_x = np.round((struct_coords - ground_coords)[ind] / dx[ind], nround)
+    val, count = np.unique(poss_x, return_counts=True)
+
+    return dQ * val[np.argmax(count)]
 
 
 def get_PES_from_vaspruns(
